
# Changelog
All notable changes to tailbone-harvest will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## v0.3.0 (2024-06-10)

### Feat

- switch from setup.cfg to pyproject.toml + hatchling

## [0.2.0] - 2024-06-06
Catch-up release.
### Changed
- lots of things...

## [0.1.0] - 2022-01-29
### Added
- Initial version.
